#
# spec file for package dconf-editor
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dconf-editor
Version:        3.26.2
Release:        lp150.2.8
Summary:        Simple key-based configuration system -- Graphical Editor
License:        GPL-3.0+
Group:          System/GUI/GNOME
Url:            http://live.gnome.org/dconf
Source0:        http://download.gnome.org/sources/dconf-editor/3.26/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM dconf-editor-nb-translations.patch zaitor@opensuse.org -- Update Norwegian Bokmål translations
Patch0:         dconf-editor-nb-translations.patch
# PATCH-FIX-UPSTREAM dconf-editor-fix-localized-strings-problem.patch zaitor@opensuse.org -- Fix problem on localized strings
Patch1:         dconf-editor-fix-localized-strings-problem.patch
# PATCH-FIX-UPSTREAM dconf-editor-fix-rows-issue.patch bgo#790025 zaitor@opensuse.org -- Fix rows option
Patch2:         dconf-editor-fix-rows-issue.patch

BuildRequires:  appstream-glib-devel
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.33.1
BuildRequires:  pkgconfig(dconf) >= 0.25.1
BuildRequires:  pkgconfig(glib-2.0) >= 2.46.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxml-2.0)
# Special case: we obsolete dconf-lang < 0.24, as at that time, dconf-editor was part of dconf.
# The gettext domain for dconf-editor remained dconf
Obsoletes:      dconf-lang < 0.24
Recommends:     %{name}-lang

%description
dconf is a low-level configuration system. Its main purpose is to
provide a backend to GSettings on platforms that don't already
have configuration storage systems.

This package provides a graphical editor for dconf database.

%lang_package

%prep
%autosetup -p1

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/ca.desrt.dconf-editor.desktop SystemSetup X-GNOME-PersonalSettings
%find_lang dconf

%files
%defattr(-, root, root)
%doc COPYING
%{_bindir}/dconf-editor
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/ca.desrt.dconf-editor.appdata.xml
%{_datadir}/applications/ca.desrt.dconf-editor.desktop
%{_datadir}/dbus-1/services/ca.desrt.dconf-editor.service
%{_datadir}/glib-2.0/schemas/ca.desrt.dconf-editor.gschema.xml
%{_datadir}/icons/hicolor/*/apps/dconf-editor*
%{_mandir}/man1/dconf-editor.1%{?ext_man}

%files lang -f dconf.lang
%defattr(-,root,root)

%changelog
* Sun Dec 24 2017 zaitor@opensuse.org
- Add dconf-editor-nb-translations.patch: Update Norwegian Bokmål
  translations.
- Add dconf-editor-fix-localized-strings-problem.patch: Fix problem
  on localized strings.
- Add dconf-editor-fix-rows-issue.patch: Fix rows option
  (bgo#790025).
- Stop post(un) handling of: desktop_database_post(un),
  icon_theme_cache_post(un) and glib2_gsettings_schema_post(un), we
  have file-triggers taking care of this for us now.
* Wed Nov  1 2017 dimstar@opensuse.org
- Update to version 3.26.2:
  + Bugs fixed: bgo#788862.
  + Updated translations.
* Mon Oct  2 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + First, there is now a toggle on boolean rows for switching
    faster the key value.
  + In the same spirit, integer keys that only accepts a small
    range of values now can be directly changed, from the
    right-click popover.
  + There is also a shortcut for reseting a key to its default
    value.
  + Updated translations.
* Sat Jan 14 2017 zaitor@opensuse.org
- Update to version 3.23.4:
  + The bigger change is the switch to modern Gettext for
    translations of XML files, in place of the deprecated Intltool.
  + That came with a cleaning of Autotools code.
  + Unicode is now used where needed in every translatable english
    string.
  + There're some small changes in keys description presentation.
  + Updated translations.
- Drop intltool BuildRequires following upstreams port.
* Sat Jan 14 2017 zaitor@opensuse.org
- Update to version 3.22.3:
  + Minor code changes.
  + Updated translations.
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Appdata installation has been fixed.
  + Theming support has been improved.
  + Updated translations.
- Drop dconf-editor-fix-appdata-install.patch: Fixed upstream.
  Following this, remove gnome-common BuildRequires and
  gnome-autogen run, we no longer carry any patches.
* Thu Sep 22 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Appdata file validation fixes.
  + Updated translations.
- Add appstream-glib-devel BuildRequires: New dependency.
- Add dconf-editor-fix-appdata-install.patch: Fix appdata
  installation. Patch from upstream git.
- Following the above, add gnome-common BuildRequires and run
  gnome-autogen as the patch touches the buildsystem.
* Wed Sep 14 2016 dimstar@opensuse.org
- Update to version 3.21.92:
  + The keyboard navigation has been improved.
  + Various a11y and i18n bugs have been fixed.
  + dconf-editor should now be able to compile with the valac flag
  - -enable-experimental-non-null, reducing the number of potential
  code errors.
  + Updated translations.
* Thu Aug 18 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Mainly polished the new UI, including improving keyboard
    navigation and updating some metadatas.
  + Updated translations.
* Fri Jul 22 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + The UI has completely evolved, into an all-in-one-window. That
    permits notably a "delay mode" in which multiple changes are
    applied at the same time (only schema by schema when there're
    some, and other keys via a DConfChangeset). Keys without schema
    can also be deleted now.
  + Updated translations.
* Fri Jul 22 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Some nullable variables are more correctly checked.
  + English wording of the welcome dialog has (again) been
    improved, and a bug appearing when closing the application with
    the app-menu has been corrected.
  + Updated translations.
* Fri Jul 22 2016 fcrozat@suse.com
- Recommends lang package for translations (bsc#988528).
* Thu Jun 30 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Do not use a spinbutton for long int.
  + Updated translations.
* Wed May 25 2016 idonmez@suse.com
- Update to GNOME 3.20.2 FATE#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + The english wording of the welcome dialog has (again) been
    improved, and a bug appearing when closing the application with
    the app-menu has been corrected.
  + Updated translations.
- Drop dconf-editor-quit-app-correctly.patch: Fixed upstream.
* Mon May  9 2016 fcrozat@suse.com
- Update to GNOME 3.20 -- FATE#318572.
* Mon Apr 25 2016 zaitor@opensuse.org
- Add dconf-editor-quit-app-correctly.patch: Correctly quit with
  app-menu action, patch from upstream git.
- Stop passing V=1 to make, we do debugging locally.
* Thu Apr 14 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + An english typo has been corrected in the welcome dialog, and
    translations files have been updated accordingly.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Some problems have appeared related to the sizing of the
    key-editor dialogs, and will need more testing with a clean
    Gtk+ release, even if all looks corrected.
  + An infinite loop has also be spotted when trying to reset all
    keys of a folder containing keys without schema.
  + Also, a CSS resource with one rule only has been added to look
    better when using the “Big Text” accessibility feature.
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + The presentation of a key’s “default value” now takes care of
    distributor and admin overrides, instead of showing the default
    value proposed in the gschema.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + This release has seen some improvements to the keyboard
    usability, with some new shortcuts added, and an help overlay
    to document them (requiring a GTK+ 3.19 at least). Other
    changes include some more metadata in the AppData file (used by
    software centers to know about the application), and minor
    corrections caused by recent GTK+ changes.
  + Updated translations.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Added a notification for the multiple “copy” actions.
  + Added a new menu for actions on the view (notably a “reset
    visible keys” action – no recursion for now).
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Removed an unnecessary big hack, and improved some other little
    things here and there.
  + Updated translations.
* Sat Nov 21 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + dconf-editor is now distributed under GPL 3.
  + Use GSettingsSchema to access schemas informations, and
    GSettings to edit settings when that’s possible.
  + UI of the keys list has been updated to use a GtkListBox, more
    accessible, more usable, cleaner.
  + Misc. other changes.
  + Updated translations.
- Drop dconf-use-g_settings_get_default_value.patch: Fixed
  upstream.
- Update license tag to GPL-3.0+, following upstreams relicensing
  work.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fixed a crash happening when a range was set without either a
    min or a max value.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + No changes since 3.17.92.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 3.17.91:
  + The output of --version is now printed on stdout, as suggested
    by GNU. That's the only technical change, all looks good.
  + Updated translations.
* Wed Aug 19 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + No big technical change for the beta, just some preparations
    for the next cycle.
  + Updated translations.
* Tue Apr 28 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Beginning of cleaning, both of the code (UI template,
    GResource…) and of the UI (unnecessary shadows removed,
    widgets' margins, minimum width of the panel…).
  + Gtk+ 3.14 is now required, with also a recent Valac.
- Disable dconf-use-g_settings_get_default_value.patch for now,
  needs rebase if still needed. Investigate later.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Add symbolic icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + The main correction since 3.15.91 is the add back of the
    manpage, forgotten during the split. Because of that, dconf
    0.23.2 is now explicitely required.
  + The AppData file also validates again.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Initial package, version 3.15.91.
  + dconf-editor was split out upstream into its own source
    repository.
- Move patch dconf-use-g_settings_get_default_value.patch from
  dconf to dconf-editor.
